@@ -442,8 +442,15 @@ CURRENCIES = {
     "C.UTF-8": "$",
     "C.UTF8": "$",
 }
-LANG = os.environ["LANG"]
-CURRENCY = CURRENCIES[LANG]
+
+# Find the currency string
+for LC in ("LC_CTYPE", "LANG"):
+    try:
+        LC_VAL = os.environ[LC]
+        CURRENCY = CURRENCIES[LC_VAL]
+        break
+    except KeyError:
+        pass
 
 
 @pytest.mark.parametrize(
@@ -535,6 +542,7 @@ def test_roundtrip_oid(con, test_input, oid):
         [Timedelta(seconds=30), "interval", None],
         [Time(4, 5, 6), "time", None],
         [Date(2001, 2, 3), "date", None],
+        ["infinity", "date", None],
         [Datetime(2001, 2, 3, 4, 5, 6), "timestamp", None],
         [Datetime(2001, 2, 3, 4, 5, 6, 0, Timezone.utc), "timestamptz", None],
         [True, "bool", 10],
